/// <reference types="node" />
import type { Document } from 'mongodb';
export interface EmailPasswordAuthOptions {
    email: string;
    password: string;
}
export interface ApiKeyAuthOptions {
    apiKey: string;
}
export interface CustomJwtAuthOptions {
    jwtTokenString: string;
}
export type AuthOptions = EmailPasswordAuthOptions | ApiKeyAuthOptions | CustomJwtAuthOptions;
export interface MongoClientConstructorOptions {
    dataSource: string;
    auth: AuthOptions;
    endpoint: string;
    fetch?: typeof fetch;
}
export declare class MongoClient {
    dataSource: string;
    endpoint: string;
    fetch: typeof fetch;
    headers: import("undici-types").Headers;
    constructor({ dataSource, auth, endpoint, fetch: customFetch }: MongoClientConstructorOptions);
    database(name: string): Database;
}
export declare class Database {
    name: string;
    client: MongoClient;
    constructor(name: string, client: MongoClient);
    collection<T = Document>(name: string): Collection<T>;
}
export declare class Collection<T> {
    name: string;
    database: Database;
    client: MongoClient;
    constructor(name: string, database: Database);
    insertOne(doc: T): Promise<{
        insertedId: string;
    }>;
    insertMany(docs: T[]): Promise<{
        insertedIds: string[];
    }>;
    findOne(filter: Document, { projection }?: {
        projection?: Document;
    }): Promise<T>;
    find(filter?: Document, { projection, sort, limit, skip }?: {
        projection?: Document;
        sort?: Document;
        limit?: number;
        skip?: number;
    }): Promise<T[]>;
    updateOne(filter: Document, update: Document, { upsert }?: {
        upsert?: boolean;
    }): Promise<{
        matchedCount: number;
        modifiedCount: number;
        upsertedId?: string;
    }>;
    updateMany(filter: Document, update: Document, { upsert }?: {
        upsert?: boolean;
    }): Promise<{
        matchedCount: number;
        modifiedCount: number;
        upsertedId?: string;
    }>;
    replaceOne(filter: Document, replacement: Document, { upsert }?: {
        upsert?: boolean;
    }): Promise<{
        matchedCount: number;
        modifiedCount: number;
        upsertedId?: string;
    }>;
    deleteOne(filter: Document): Promise<{
        deletedCount: number;
    }>;
    deleteMany(filter: Document): Promise<{
        deletedCount: number;
    }>;
    aggregate<T = Document>(pipeline: Document[]): Promise<T[]>;
    countDocuments(filter?: Document, options?: {
        limit?: number;
        skip?: number;
    }): Promise<number>;
    estimatedDocumentCount(): Promise<number>;
    callApi(method: string, extra: Document): Promise<any>;
}
